@@ -40,27 +40,31 @@ class Client:
         sentences_per_chunk=2,
         sentence_overlap=0,
         image_preprocessing_method=None,
+        settings_dict=None
     ) -> Dict[str, Any]:
-        """
+        """Create the index.
 
         Args:
-            index_name:
+            index_name: name of the index.
             treat_urls_and_pointers_as_images:
             model:
             normalize_embeddings:
             sentences_per_chunk:
             sentence_overlap:
             image_preprocessing_method:
-
+            settings_dict: if specified, overwrites all other setting
+                parameters, and is passed directly as the index's
+                index_settings
         Returns:
-
+            Response body, containing information about index creation result
         """
         return Index.create(
             config=self.config, index_name=index_name,
             treat_urls_and_pointers_as_images=treat_urls_and_pointers_as_images,
             model=model, normalize_embeddings=normalize_embeddings,
             sentences_per_chunk=sentences_per_chunk, sentence_overlap=sentence_overlap,
-            image_preprocessing_method=image_preprocessing_method
+            image_preprocessing_method=image_preprocessing_method,
+            settings_dict=settings_dict
         )
 
     def delete_index(self, index_name: str) -> Dict[str, Any]:
@@ -81,75 +85,36 @@ class Client:
         """Get the index.
         This index should already exist.
 
-        Parameters
-        ----------
-        index_name:
-            UID of the index.
+        Args:
+            index_name: name of the index
 
-        Returns
-        -------
-        index:
+        Returns:
             An Index instance containing the information of the fetched index.
 
-        Raises
-        ------
-        s2SearchApiError
-            An error containing details about why marqo can't process your request. marqo error codes are described here: https://docs.marqo.com/errors/#marqo-errors
+        Raises:
         """
         ix = Index(self.config, index_name)
-        # verify it exists
-        # maybe delete - use stats end point for now
+        # verify it exists:
         self.http.get(path=f"indexes/{index_name}/stats")
         return ix
 
     def index(self, index_name: str) -> Index:
-        """Create a local reference to an index identified by UID, without doing an HTTP call.
-        Calling this method doesn't create an index in the marqo instance, but grants access to all the other methods in the Index class.
+        """Create a local reference to an index identified by index_name,
+        without doing an HTTP call.
 
-        Parameters
-        ----------
-        index_name:
-            UID of the index.
+        Calling this method doesn't create an index on the Marqo instance, but
+         grants access to all the other methods in the Index class.
 
-        Returns
-        -------
-        index:
+        Args:
+            index_name: name of the index
+
+        Returns:
             An Index instance.
         """
         if index_name is not None:
             return Index(self.config, index_name=index_name)
         raise Exception('The index UID should not be None')
 
-    def get_version(self) -> Dict[str, str]:
-        """Get version marqo
-
-        Returns
-        -------
-        version:
-            Information about the version of marqo.
-
-        Raises
-        ------
-        s2SearchApiError
-            An error containing details about why marqo can't process your request. marqo error codes are described here: https://docs.marqo.com/errors/#marqo-errors
-        """
-        return self.http.get(self.config.paths.version)
-
-    def version(self) -> Dict[str, str]:
-        """Alias for get_version
-
-        Returns
-        -------
-        version:
-            Information about the version of marqo.
-
-        Raises
-        ------
-        s2SearchApiError
-            An error containing details about why marqo can't process your request. marqo error codes are described here: https://docs.marqo.com/errors/#marqo-errors
-        """
-        return self.get_version()
-
     @staticmethod
     def _base64url_encode(
         data: bytes
